/********************************************************* 
; Processor specific definitions for Cypress CY7C64011
**********************************************************/

#ifndef __640XX_H
#define __640XX_H

/**************************************************************************
 Processor Core 
***************************************************************************/
#pragma has BCPU;


/****************************************************************************
 Register Definition 
*****************************************************************************/
registera AC;
registerx IX;
registercc CC;	/*	CC.Z : Zero Flag
					CC.C : Carry Flag  */


/***************************************************************************** 
RAM Definition  
******************************************************************************/

#define RAM_SIZE                0xFF /* 256 bytes				*/
#define RAM_START 		  		0x00 /* start ram at address 0	*/
#define STACK_SIZE              0x40 /* 64 bytes of stack		*/
#define USB_FIFO_SIZE           0x48 /* total size of three fifos is 8+32+32=72 bytes */

#define STACK_START             RAM_START
#define REGISTER_START          RAM_START+STACK_SIZE
#define REGISTER_SIZE           RAM_SIZE - USB_FIFO_SIZE - STACK_SIZE
#define SPAD_SIZE               12

#pragma memory RAM [REGISTER_SIZE] @ REGISTER_START;

#ifndef NOLOCAL
#pragma memory LOCAL [0] @ RAM_SIZE-USB_FIFO_SIZE-SPAD_SIZE;
#endif /* NOLOCAL */

#pragma memory STACK[ STACK_SIZE ] @ RAM_START;

/*****************************************************************************
 ROM Definition  
******************************************************************************/
#define ROM_SIZE	 	0x0FFF	/* 4K bytes */ 
#define ROM_START		0x1A    /* after interrupt vectors */
#pragma memory ROM [ROM_SIZE - ROM_START ] @ ROM_START;
  

/****************************************************************************
 Interrupt Vectors 
*****************************************************************************/

#pragma vector main		   		@ 0x00; /* reset vector 		*/
#pragma vector Bus_reset		@ 0x02; /* Reserved interrupt	*/
#pragma vector _error			@ 0x04; /* 128us interrupt 		*/
#pragma vector _1ms_timer		@ 0x06; /* 1.024ms interrupt 	*/
#pragma vector Endpoint0	 	@ 0x08;	/* USB Address A endpoint 0 interrupt */
#pragma vector Endpoint1 		@ 0x0A;	/* USB Address A endpoint 1 interrupt */
#pragma vector Endpoint2	 	@ 0x0C;	/* USB Address A endpoint 2 interrupt */
#pragma vector _error			@ 0x0E;	/* USB Address B endpoint 0 interrupt */
#pragma vector _error			@ 0x10;	/* USB Address B endpoint 1 interrupt */
#pragma vector _error			@ 0x12; /* Reserved interrupt	*/
#pragma vector _error 			@ 0x14; /* DAC interrupt		*/
#pragma vector _error			@ 0x16; /* GPIO/HAPI interrupt	*/
#pragma vector _error			@ 0x18; /* I2C interrupt		*/	


/****************************************************************************/
/* General Purpose I/O Ports */
/****************************************************************************/
// register definitions

#pragma	portrw	port0			@	0x00; // GPIO data port 0
#pragma	portrw	port1			@	0x01; // GPIO data port 1
#pragma	portrw	port2			@	0x02; // GPIO data port 2
#pragma	portrw	port3			@	0x03; // GPIO data port 3

#pragma	portw	port0_int		@	0x04; // Interrupt enable for Port 0
#pragma	portw	port1_int		@	0x05; // Interrupt enable for Port 1
#pragma	portw	port2_int		@	0x06; // Interrupt enable for Port 2
#pragma	portw	port3_int		@	0x07; // Interrupt enable for Port 3

#pragma	portrw	gpio_config		@	0x08; // GPIO configuration for all ports
#define 	PORT3_RESISTIVE 	0x00
#define 	PORT3_CMOS      	0x80
#define 	PORT3_OPENDRAIN 	0xC0
#define 	PORT2_RESISTIVE 	0x00
#define 	PORT2_CMOS      	0x20
#define 	PORT2_OPENDRAIN 	0x30
#define 	PORT1_RESISTIVE 	0x00
#define 	PORT1_CMOS      	0x08
#define 	PORT1_OPENDRAIN 	0x0C
#define 	PORT0_RESISTIVE 	0x00
#define 	PORT0_CMOS      	0x02
#define 	PORT0_OPENDRAIN 	0x03

#pragma	portrw	hapi_i2c_config	@	0x09; // HAPI and I2C interface configuration
#define		I2C_POSITION		0x80
#define		LEMPTY_POLARITY		0x20
#define		DRDY_POLARITY		0x10
#define		LEMPTY				0x08
#define		DRDY				0x04
#define		HAPI_WIDTH1			0x02
#define		HAPI_WIDTH0			0x01		


#pragma	portrw	usb_address		@	0x10; // USB device address
#define		ADDRESS_ENABLE		0x80
#define		ADDRESS_MASK		0x7F

#pragma	portrw	ep0_count		@	0x11;	// Endpoint 0 counter
#define		DATA_TOGGLE			0x80
#define		DATA_VALID			0x40
#define		BYTE_COUNT			0x3F
#pragma portrw	ep0_mode		@	0x12; // Endpoint 0 configuration
#define		EP0_SETUP			0x80
#define		EP0_IN				0x40
#define		EP0_OUT				0x20
#define		EP0_ACK				0x10
#define		MODE_MASK			0x0F
#pragma portrw	ep1_count		@	0x13; // Endpoint 1 counter
#pragma portrw	ep1_mode		@	0x14; // Endpoint 1 configuration
#pragma	portrw	ep2_count		@	0x15; // Endpoint 2 counter
#pragma portrw	ep2_mode		@	0x16; // Endpoint 2 configuration
#define		EP_STALL			0x80
#define		EP_ACK				0x10

#pragma	portrw	usb_status		@	0x1F; // USB upstream status and control
#define		ENDPOINT_SIZE		0x80
#define		ENAPOINT_MODE		0x40
#define		D_PLUS				0x20
#define		D_MINUS				0x10
#define		BUS_ACTIVITY		0x08
#define		CONTROL2			0x04
#define		CONTROL1			0x02
#define		CONTROL0			0x01

#define		NOT_FORCING			0x00
#define		FORCE_J				0x01
#define		FORCE_K				0x02
#define		FORCE_SE0			0x03
#define		FORCEBOTH_LOW		0x04
#define		FORCESDATA_LOW		0x05
#define		FORCESCLK_LOW		0x06
#define		FORCE_HIZ			0x07

#pragma	portrw	global_int		@	0x20; // Global interrupt enable
#define		I2C_INT				0x40
#define		GPIO_HAPI_INT		0x20
#define		DAC_INT				0x10
#define		_1MS_INT			0x04
#define		_128US_INT			0x02
#define		USB_RESET_INT		0x01

#pragma	portrw	endpoint_int	@	0x21; // USB endpoint interrupt enable
#define		EP4_INT				0x10
#define		EP3_INT				0x08
#define		EP2_INT				0x04
#define		EP1_INT				0x02
#define		EP0_INT				0x01

#pragma	portr	timer_lsb		@	0x24; // Lower eight bits of timer
#pragma	portr	timer_msb		@	0x25; // Upper six bits of timer
#pragma	portw	watchdog		@	0x26; // Clear watchdog Timer

#pragma	portrw	i2c_control_status	@ 0x28; // I2C status and control register
#define		MSTR_MODE			0x80
#define		CONTINUE_BUSY		0x40
#define		XMIT_MODE			0x20
#define		ACK					0x10
#define		ADDR				0x08
#define		ARB_LOST_RESTART	0x04
#define		RECEIVED_STOP		0x02
#define		I2C_ENABLE			0x01
#pragma	portrw	i2c_data		@	0x29; // I2C data register

#pragma	portrw	dac_data		@	0x30;	// DAC port data register
#pragma	portw	dac_int			@	0x31; // DAC port interrupt enable
#pragma	portw	dac_int_polarity@	0x32; // DAC port interrupt polarity
#pragma	portw	dac0			@	0x38; // DAC 0
#pragma	portw	dac1			@	0x39; // DAC 1
#pragma	portw	dac2			@	0x3A; // DAC 2
#pragma	portw	dac3			@	0x3B; // DAC 3
#pragma	portw	dac4			@	0x3C; // DAC 4
#pragma	portw	dac5			@	0x3D; // DAC 5
#pragma	portw	dac6			@	0x3E; // DAC 6
#pragma	portw	dac7			@	0x3F; // DAC 7

#pragma	portrw	ep3_count		@	0x41; // Endpoint 3 counter
#pragma	portrw	ep3_mode		@	0x42; // Endpoint 3 configuration
#pragma	portrw	ep4_count		@	0x43; // Endpoint 4 counter
#pragma	portrw	ep4_mode		@	0x44; // Endpoint 4 configuration

#pragma	portrw	control			@	0xFF; // Processor status and control
#define		IRQ_PENDING	 		0x80
#define		WATCHDOG_RESET	 	0x40
#define		USB_RESET		 	0x20
#define		POWERON_RESET	 	0x10
#define		SUSPEND			 	0x08
#define		INTERRUPT_MASK	 	0x04
#define		SINGLE_STEP		 	0x02
#define		RUN				 	0x01


//*************************************
// USB mode encoding

#define	DISABLE					0x00
#define	NAK_IN_OUT				0x01
#define	STATUS_OUT_ONLY			0x02
#define	STALL_IN_OUT			0x03
#define	IGNORE_IN_OUT			0x04
#define	ISOCHRONOUS_OUT			0x05
#define	STATUS_IN_ONLY			0x06
#define	ISOCHRONOUS_IN			0x07
#define	NAK_OUT					0x08
#define	ACK_OUT					0x09
#define	NAK_OUT_STATUS_IN		0x0A
#define	ACK_OUT_STATUS_IN		0x0B
#define	NAK_IN					0x0C
#define	ACK_IN					0x0D
#define	NAK_IN_STATUS_OUT		0x0E
#define	ACK_IN_STATUS_OUT		0x0F


//*************************************
// general use constants

#define	SET						0xFF
#define	CLEAR					0x00


//*************************************
// definitions for assembler substitution

#define PUSHA() #asm( push	A )
#define PUSHX() #asm( push	X )
#define POPA()	#asm( pop	A )
#define POPX()  #asm( pop	X )

#define	MOVE_DSP() #asm( swap	A, dsp )
#define	MOVE_PSP() #asm( mov	psp, A )


#define data_stack	0xD8

#define SEC()	#asm( db 0x19, 0xff, 0x3d )
#define RLC()	#asm( db 0x3d )


/* int16 l = 0x1234; --> loc 0020:12, 0021:34 */
#define __BIG_ENDIAN /* most significant byte is stored in small address */

#endif /* __640_H */
