//*********************************************************
//
//	cymdut.h
//
//	Header file for CyMicro DUT board
//
//	This file contains function prototypes for the functions
//  found in cymdut.c and the USB descriptor tables
//
//*********************************************************

#ifndef __CYMDUT_H
#define __CYMDUT_H

typedef	unsigned char	Byte;

/* endpoint 0 standard request functions */
void	Get_status(void);
void	Clear_feature(void);
void	Set_feature(void);
void	Set_address(void);
void	Get_descriptor(void);
void	Get_configuration(void);
void	Set_configuration(void);
void	Get_interface(void);
void	Set_interface(void);
void	Request_not_supported(void);

void	regRead(void);
void	regWrite(void);
void	i2c(void);

void	Que(void);


/* endpoint 0 standard transaction initialization functions */
void	Initialize_control_read(void);
void	Initialize_control_write(void);
void	Initialize_no_data_control(void);

/* endpoint 0 IN token handler functions */
void	Control_read_data_stage(void);
void	Control_write_status_stage(void);
void	No_data_control_status_stage(void);

/* endpoint 0 OUT token handler functions */
void	Control_read_status_stage(void);
void	Control_write_data_stage(void);
void	No_data_control_error(void);

/* Primitive function to implement interface */
void PldWrite(unsigned char);
void PldRead();

// Command Types
#define	SRAM			1
#define	PLD				2
#define PSOC			3
#define BULKMODES		4
#define DUT_MEM			5
#define DUT_IO			6
// BulkModes
#define BULK_DEF		0
#define	QUE				1
#define PROGRAM			2
#define VERIFY			3

#define PSOC_READ		0x1C
#define PSOC_WRITE		0x0C
#define PLD_CLK			0x00
#define	PLD_CLOCKCTL	0

// PSOC Control address definitions
#define PSOC_RESET		0  //(PSOC XRES)
#define PSOC_KEY		1  //(Acquire Test Mode)
#define PSOC_IO			2  //(Set up an IO transfer address)
#define PSOC_MEM		3  //(Set up a MEM transfer address)
#define PSOC_DATA		4  //(Read PSOC data, Write PSOC data)
#define PSOC_CLOCKLO	5  //(Write to LS byte, and start clocking)
#define PSOC_CLOCKHI	6  //(Write to MS byte)
#define PSOC_POLL		7  //(Read SD from PSOC)
#define PSOC_CLK		8
#define	PSOC_I2C		9	// Enable I2C to PSOC

//	Leading 3 bits of packet

#define	TCOP_IOR		7
#define	TCOP_IOW		6
#define	TCOP_MR			5
#define	TCOP_MW			4

//*********************************************************
//*********************************************************
// This is where you put your USBIF assigned Vendor ID (VID)
// and the Product ID (PID) that you assign to the product.


#define	VID_HIGH_BYTE	0x04		// This is the Cypress VID
#define	VID_LOW_BYTE	0xB4		// assigned by the USBIF

#define	PID_HIGH_BYTE	0xF1		// This is an arbitrarily
#define	PID_LOW_BYTE:	0x01		// assigned PID

// this device is either SELF_POWERED or BUS_POWERED
// the SELF_POWERED and BUS_POWERED constants are defined in Usb.h
#define	POWER_SRC		SELF_POWERED

// This value is in mA, and is set to 0 for self powered devices
#define	CURRENT_DRAW	0

// This value sets the default number of milliseconds before data
// is sent if the buffer is not full. 0 = no timeout.
// valid values of this parameter are between 0 and 255
#define	IN_TIMEOUT		0

//********************************************************
//       		USB DESCRIPTOR TABLES
//********************************************************


const char config_desc_table[ ] =
{
	CONFIG_LENGTH,			// bLength (9 bytes)
	CONFIGURATION,			// bDescriptorType (CONFIGURATION)
	CONFIG_LENGTH + INTERFACE_LENGTH + 2*ENDPOINT_LENGTH, 
	0,						// wTotalLength (config+interface+ endp(s))
	1,						// bNumInterfaces (1)
	1,						// bConfigurationValue (1)
	0,						// iConfiguration (string not supported)
	POWER_SRC,				// bmAttributes (set to constant at beginning of this file)
	CURRENT_DRAW/2,			// MaxPower (set to constant at beginning of this file)
   /* interface_desc_table */
	INTERFACE_LENGTH,		// bLength (9 bytes)
	INTERFACE,				// bDescriptorType (INTERFACE)
	0,						// bInterfaceNumber (0)
	0,						// bAlternateSetting (0)
	2,						// bNumEndpoints (2) 
	0,						// bInterfaceClass (none)
	0,						// bInterfaceSubClass (none)
	0,						// bInterfaceProtocol (none)
	0,						// iInterface (not supported)
   /* endpoint1_desc_table */
	ENDPOINT_LENGTH,		// bLength (7 bytes)
	ENDPOINT,				// bDescriptorType (ENDPOINT)
	(IN | 1),				// bEndpointAddress (IN endpoint, endpoint 1)
	BULK,					// bmAttributes (bulk)
	32, 0,					// wMaxPacketSize (32 bytes)
	0,						// bInterval (ignored)
   /* endpoint2_desc_table */
	ENDPOINT_LENGTH,		// bLength (7 bytes)
	ENDPOINT,				// bDescriptorType (ENDPOINT)
	(OUT | 2),				// bEndpointAddress (OUT endpoint, endpoint 2)
	BULK,					// bmAttributes (bulk)
	32, 0,					// wMaxPacketSize (32 bytes)
	0						// bInterval (ignored)
};



const char device_desc_table[ ] = 
{
	DEVICE_LENGTH,	// bLength (18 bytes)
	DEVICE,			// bDescriptorType (device descriptor)
	0x10, 0x01,		// bcdUSB (ver 1.1)
	0,				// bDeviceClass (each interface specifies class info)
	0,				// bDeviceSubClass (not specified)
	0,				// bDeviceProtocol (not specified)
	8,				// bMaxPacketSize0 (8 bytes)
	VID_LOW_BYTE, VID_HIGH_BYTE,		// idVendor (Cypress vendor ID)
	PID_LOW_BYTE, PID_HIGH_BYTE,		// idProduct (Cypress USB mouse product ID)
	0x00, 0x01,		// bcdDevice (1.00) 
	1,				// iManufacturer (Cypress Semiconductor)
	2,				// iProduct (Cypress Embedded UART)
	0,				// iSerialNumber (not supported)
	1				// bNumConfigurations (1)
};


const char device_status_wakeup_disabled [ ] =
{
    ((POWER_SRC >> 6) & 0x01), 0x00		/* remote wakeup disabled, selected power */
};

const char device_configured_table[] =
{
	0x01			/* device in configured state */
};

const char device_unconfigured_table[] =
{
	0x00			/* device in unconfigured state */
};

const char endpoint_nostall_table[] =
{
	0x00, 0x00		/* endpoint not stalled */
};

const char endpoint_stall_table[] =
{
	0x01, 0x00		/* endpoint stalled */
};

const char interface_status_table[] =
{
	0x00, 0x00		/* default response */
};

const char interface_alternate_table[] =
{
	0x00			/* only valid alternate setting */
};

const char ilanguage_string[] =
{
    4,          		/* Length */
    STRING,         	/* Type (3=string) */
    9,          		/* Language:  English */
    4          			/* Sub-language: US */
};

const char imanufacturer_string[] =
{
    42,          		/* Length */
    STRING,          	/* Type (3=string) */
    'C',0,'y',0,'p',0,'r',0,'e',0,'s',0,'s',0,' ',0,
    'M',0,'i',0,'c',0,'r',0,'o',0,'S',0,'y',0,'s',0,'t',0,'e',0,'m',0,'s',0
};

const char iproduct_string[] =
{
    40,          		/* Length */
    STRING,          	/* Type (3=string) */
    'P',0,'S',0,'o',0,'C',0,
    ' ',0,
    'I',0,'n',0,'v',0,'e',0,'n',0,'t',0,'i',0,'o',0,'n',0,'B',0,'o',0,'a',0,'r',0,'d',0
};

#endif

