
//*********************************************************
// USB Descriptor and Request constants
//	source p172,,175 USB specification
//*********************************************************

#ifndef __USB_H
#define __USB_H

//	Characterists of bmRequest Value
//
// D7	Data xfer direction
//	0 = Host to device
//	1 = Device to host
//
// D6..5	Type
//	0 = Standard
//	1 = Class
//	2 = Vendor
//	3 = Reserved
//
// D4..0	Recipient
//	0 = Device
//	1 = Interface
//	2 = Endpoint
//	3 = Other
//	4..31 = Reserved


//*************************************
// bmRequestType
#define	HOSTTODEVICE			0x00
#define	DEVICETOHOST			0x80

#define	STANDARD_TYPE			0x00
#define	CLASS_TYPE				0x20
#define	VENDOR_TYPE				0x40
#define	RESERVED_TYPE			0x60

#define	DEVICE_RECIPIENT		0x00
#define	INTERFACE_RECIPIENT		0x01
#define	ENDPOINT_RECIPIENT		0x02
#define	OTHER_RECIPIENT			0x03

//*************************************
// bRequest
#define	GET_STATUS				0x00
#define	CLEAR_FEATURE			0x01
#define	SET_FEATURE				0x03
#define	SET_ADDRESS				0x05
#define	GET_DESCRIPTOR			0x06
#define	SET_DESCRIPTOR			0x07
#define	GET_CONFIGURATION		0x08
#define	SET_CONFIGURATION		0x09
#define	GET_INTERFACE			0x0A
#define	SET_INTERFACE			0x0B
#define	SYNCH_FRAME				0x0C

// *************************************
// Descriptor Types and Lengths
#define	DEVICE					0x01
#define	DEVICE_LENGTH			0x12
#define	CONFIGURATION			0x02
#define	CONFIG_LENGTH			0x09
#define	STRING					0x03
#define	INTERFACE				0x04
#define	INTERFACE_LENGTH		0x09
#define	ENDPOINT				0x05
#define	ENDPOINT_LENGTH			0x07

//*************************************
// Feature Selectors
#define	DEVICE_REMOTE_WAKEUP	0x01
#define	ENDPOINT_STALL			0x00

//*************************************
// HID Class Request Types
#define	GET_REPORT				0x01
#define	GET_IDLE				0x02
#define	GET_PROTOCOL			0x03
#define	SET_REPORT				0x09
#define	SET_IDLE				0x0A
#define	SET_PROTOCOL			0x0B

//*************************************
// HID report formats
#define	HID_BOOT				0x00
#define	HID_REPORT				0x01

//*************************************
// ENDPOINT 0 SETUP REQUEST FIELDS
#define	BMREQUESTTYPE			0x00
#define	BREQUEST				0x01
#define	WVALUELO				0x02
#define	WVALUEHI				0x03
#define	WINDEXLO				0x04
#define	WINDEXHI				0x05
#define	WLENGTHLO				0x06
#define	WLENGTHHI				0x07

//*************************************
// bmAttributes values
#define	BUS_POWERED				0x80
#define	SELF_POWERED			0x40
#define	REMOTE_WAKEUP			0x02

#define	CONTROL					0x00
#define	ISOCHRONOUS				0x01
#define	BULK					0x02
#define	INTERRUPT				0x03

//*************************************
// bEndpointAddress values
#define	IN						0x80
#define	OUT						0x00

#endif